..
  SPDX-FileCopyrightText: 2024 Free Software Foundation Europe e.V. <https://fsfe.org>

  SPDX-License-Identifier: CC-BY-SA-4.0

Command-line reference
======================

These are the manpages for ``reuse``. They contain helpful-but-succinct
information about the functioning of the tool.

.. toctree::
   :maxdepth: 1

   reuse
   reuse-annotate
   reuse-convert-dep5
   reuse-download
   reuse-lint
   reuse-lint-file
   reuse-spdx
   reuse-supported-licenses
